@@ -26,10 +26,17 @@ db.create_metric(
   first = int(time.time()-100), last = int(time.time()), data_points_list = [], dynamodb=dynamodb
 )'''
 
+key_dict = {
+  "component_id" : "prd_db",
+  "last_fetched_ts" : 1600214100
+}
+
+a = utils.get_item(key_dict, 'logs.cloud_metric_fetching_log', dynamodb)
+print(a)
 #a = db.query_most_recent_metric_fetching_log('prd_db', dynamodb)
 #print(a)
-#a = db.query_most_recent_metric_fetching_log('prd_db_2', dynamodb)
+# = db.query_most_recent_metric_fetching_log('prd_db_2', dynamodb)
 #print(a['last_fetched_ts'])
 
-key_condition = Key('component_id').eq('prd_db')
-print(utils.query_by_key_min_max(key_condition, 'logs.cloud_metric_fetching', False, dynamodb))
\ No newline at end of file
+#key_condition = Key('component_id').eq('prd_db')
+#print(utils.query_by_key_min_max(key_condition, 'logs.cloud_metric_fetching', False, dynamodb))
\ No newline at end of file
